==> ims.j2jsoftwaresolutions.in08_09.tgz: ims.j2jsoftwaresolutions.in/webservices/class.Semesters.php <==
<?php
class Semesters {
    
    public static function addNew() {
        
        global $mysql;
        
        if (isset($_POST['Code'])) {
            if (strlen(trim($_POST['Code']))==0) {
                return json_encode(array("status"=>"failure","message"=>"Please Enter Code","div"=>"Code"));    
            } else {
                $dupCode = $mysql->select("select * from ".Tabels::Semesters." where Code='".trim($_POST['Code'])."'");
                if (sizeof($dupCode)>0) {
                    return json_encode(array("status"=>"failure","message"=>"Already Exists","div"=>"Code"));    
                }   
            }
        } 
         
        if (strlen(trim($_POST['Semester']))==0) {
            return json_encode(array("status"=>"failure","message"=>"Please enter Semester","div"=>"Semester"));    
        } else {
            $dupCode = $mysql->select("select * from ".Tabels::Semesters." where Semester='".trim($_POST['Semester'])."'");
            if (sizeof($dupCode)>0) {
                return json_encode(array("status"=>"failure","message"=>"Already Exists","div"=>"Semester"));    
            }
        }
        $id = $mysql->insert(Tabels::Semesters,array("Code"         => trim($_POST['Code']),
                                                         "Semester" => trim($_POST['Semester']),
                                                         "Remarks"      => trim($_POST['Remarks']),
                                                         "CreatedOn"    => date("Y-m-d H:i:s"),
                                                         "Status"     => '1'));
        if ($id>0) {
            return json_encode(array("status"=>"success","message"=>"Successfuly created","div"=>""));
        } else {
            return json_encode(array("status"=>"failure","message"=>"Unable to create, please contact system administrator","div"=>""));
        }
     }
     
    public static function doUpdate() {
         
         global $mysql;
         
         if (strlen(trim($_POST['Semester']))==0) {
             return json_encode(array("status"=>"failure","message"=>"Please enter Semester","div"=>"Semester"));    
         } else {
            $dupCode = $mysql->select("select * from ".Tabels::Semesters." where Semester='".trim($_POST['Semester'])."' and md5(ID)<>'".$_POST['ID']."'");
            if (sizeof($dupCode)>0) {
                return json_encode(array("status"=>"failure","message"=>"Aready exits","div"=>"Semester"));    
            }
        }
        
       $id= $mysql->execute("update ".Tabels::Semesters." set Semester ='".$_POST['Semester']."',
                                                              Remarks      ='".$_POST['Remarks']."',
                                                              Status     ='".$_POST['Status']."' where md5(ID)='".$_POST['ID']."'");
                                                          
       if ($id>0) {
        return json_encode(array("status"=>"success","message"=>"Updated successfully","div"=>""));
       } else {
           return json_encode(array("status"=>"failure","message"=>"unable to update".$mysql->error,"div"=>""));
       }
    }
     
    public static function remove() {
        
        global $mysql;
        
        $data_exists = $mysql->select("select * from _tbl_masters_customers where CustomerTypeNameID='".$_GET['ID']."'");
        if (sizeof($data_exists)==0) {
            $mysql->execute("delete from _tbl_masters_customertypename where CustomerTypeNameID='".$_GET['ID']."'");
           // return json_encode(array("status"=>"success","message"=>CustomerTypeErrors::Delete_Success,"data"=>CustomerTypes::listAll("array")));    
        } else {
             //return json_encode(array("status"=>"failure","message"=>CustomerTypeErrors::CustomerTypeCode_Delete_Failure.". Reason: Customer Type name has assigned ".(sizeof($data_exists))." customer(s)","div"=>""));
        }
    }

    public static function listAll() {
        global $mysql;
        $data = $mysql->select("select md5(ID) as ID,Code,Semester,Remarks,Status,CreatedOn from ".Tabels::Semesters." ");
        return json_encode(array("status"=>"success","data"=>$data));
    }

    public static function getData() {
        global $mysql;
        $data = $mysql->select("select md5(ID) as ID,Semester ,Remarks      ,Status     ,Code,CreatedOn from ".Tabels::Semesters." where md5(ID)='".$_GET['ID']."'");
        return json_encode(array("status"=>"success","data"=>$data));
    }
    
  
}
?>

==> ims.j2jsoftwaresolutions.in15_09.tgz: ims.j2jsoftwaresolutions.in/webservices/class.Semesters.php <==
<?php
class Semesters {
    
    public static function addNew() {
        
        global $mysql;
        
        if (isset($_POST['Code'])) {
            if (strlen(trim($_POST['Code']))==0) {
                return json_encode(array("status"=>"failure","message"=>"Please Enter Code","div"=>"Code"));    
            } else {
                $dupCode = $mysql->select("select * from ".Tabels::Semesters." where Code='".trim($_POST['Code'])."'");
                if (sizeof($dupCode)>0) {
                    return json_encode(array("status"=>"failure","message"=>"Already Exists","div"=>"Code"));    
                }   
            }
        } 
         
        if (strlen(trim($_POST['Semester']))==0) {
            return json_encode(array("status"=>"failure","message"=>"Please enter Semester","div"=>"Semester"));    
        } else {
            $dupCode = $mysql->select("select * from ".Tabels::Semesters." where Semester='".trim($_POST['Semester'])."'");
            if (sizeof($dupCode)>0) {
                return json_encode(array("status"=>"failure","message"=>"Already Exists","div"=>"Semester"));    
            }
        }
        $id = $mysql->insert(Tabels::Semesters,array("Code"         => trim($_POST['Code']),
                                                         "Semester" => trim($_POST['Semester']),
                                                         "Remarks"      => trim($_POST['Remarks']),
                                                         "CreatedOn"    => date("Y-m-d H:i:s"),
                                                         "Status"     => '1'));
        if ($id>0) {
            return json_encode(array("status"=>"success","message"=>"Successfuly created","div"=>""));
        } else {
            return json_encode(array("status"=>"failure","message"=>"Unable to create, please contact system administrator","div"=>""));
        }
     }
     
    public static function doUpdate() {
         
         global $mysql;
         
         if (strlen(trim($_POST['Semester']))==0) {
             return json_encode(array("status"=>"failure","message"=>"Please enter Semester","div"=>"Semester"));    
         } else {
            $dupCode = $mysql->select("select * from ".Tabels::Semesters." where Semester='".trim($_POST['Semester'])."' and md5(ID)<>'".$_POST['ID']."'");
            if (sizeof($dupCode)>0) {
                return json_encode(array("status"=>"failure","message"=>"Aready exits","div"=>"Semester"));    
            }
        }
        
       $id= $mysql->execute("update ".Tabels::Semesters." set Semester ='".$_POST['Semester']."',
                                                              Remarks      ='".$_POST['Remarks']."',
                                                              Status     ='".$_POST['Status']."' where md5(ID)='".$_POST['ID']."'");
                                                          
       if ($id>0) {
        return json_encode(array("status"=>"success","message"=>"Updated successfully","div"=>""));
       } else {
           return json_encode(array("status"=>"failure","message"=>"unable to update".$mysql->error,"div"=>""));
       }
    }
     
    public static function remove() {
        global $mysql;
        $rows = $mysql->execute("delete from ".Tabels::Semesters." where md5(ID)='".$_POST['delID']."'");
        if ($rows>0) {
            return json_encode(array("status"=>"success","message"=>"Deleted sucessfully"));    
        }
    }
    public static function listAll() {
        global $mysql;
        $data = $mysql->select("select md5(ID) as ID,Code,Semester,Remarks,Status,CreatedOn from ".Tabels::Semesters." ");
        return json_encode(array("status"=>"success","data"=>$data));
    }

    public static function getData() {
        global $mysql;
        $data = $mysql->select("select md5(ID) as ID,Semester ,Remarks      ,Status     ,Code,CreatedOn from ".Tabels::Semesters." where md5(ID)='".$_GET['ID']."'");
        return json_encode(array("status"=>"success","data"=>$data));
    }
    
  
}
?>
